Box3D

Struct Box3D 

pub struct Box3D {
    pub position: Vector3D<u64>,
    pub size: Vector3D<u64>,
    pub id: usize,
    pub origin: u16,
}
The structure of a 3-dimensional box

Fields

position: Vector3D<u64>

Corresponds to x,y,z properties

size: Vector3D<u64>

Corresponds to w,h,l properties

id: usize

ID for each box

origin: u16

Keeps a trace of how the box evolved (only for debugging)

Implementations

Source

impl Box3D

pub fn from_position_size( position: Vector3D<u64>, size: Vector3D<u64>, id: usize, origin: u16, ) -> Box3D

Create Box3D from position, and size

pub fn from_xyz_whl( x: u64, y: u64, z: u64, w: u64, h: u64, l: u64, id: usize, origin: u16, ) -> Box3D

Create Box3D from xyz, and whl

pub fn volume(&self) -> u64

Volume of the Box

pub fn fits_in(&self, other: &Box3D) -> bool

Box is smaller than other

pub fn is_in(&self, other: &Box3D) -> bool

Box is inside other in terms of size AND position

pub fn x2(&self) -> u64

pub fn y2(&self) -> u64

pub fn z2(&self) -> u64

pub fn intersects(&self, other: &Box3D) -> bool

Box strictly (doesn’t only touch) intersects other

pub fn is_covered_among(&self, boxes: &HashSetFnv<Box3D>) -> bool

Returns whether Box is covered among other Boxes

pub fn get_rotations(&self) -> Vec<Box3D>

Gets the new 6 boxes with sizes adjusted according to rotation